( cd usr/lib64 ; rm -rf libXaw3d.so.8 )
( cd usr/lib64 ; ln -sf libXaw3d.so.8.0 libXaw3d.so.8 )
( cd usr/lib64 ; rm -rf libXaw3d.so )
( cd usr/lib64 ; ln -sf libXaw3d.so.8 libXaw3d.so )
( cd usr/lib64 ; rm -rf libXaw3d.so.7 )
( cd usr/lib64 ; ln -sf libXaw3d.so.8 libXaw3d.so.7 )
( cd usr/lib64 ; rm -rf libXaw3d.so.6 )
( cd usr/lib64 ; ln -sf libXaw3d.so.7 libXaw3d.so.6 )
